pre.code   { background: #272822; color: #f8f8f2 }
pre.code  .c { color: #75715e } /* Comment */
pre.code  .err { color: #960050; background-color: #1e0010 } /* Error */
pre.code  .k { color: #66d9ef } /* Keyword */
pre.code  .l { color: #ae81ff } /* Literal */
pre.code  .n { color: #f8f8f2 } /* Name */
pre.code  .o { color: #f92672 } /* Operator */
pre.code  .p { color: #f8f8f2 } /* Punctuation */
pre.code  .cm { color: #75715e } /* Comment.Multiline */
pre.code  .cp { color: #75715e } /* Comment.Preproc */
pre.code  .c1 { color: #75715e } /* Comment.Single */
pre.code  .cs { color: #75715e } /* Comment.Special */
pre.code  .ge { font-style: italic } /* Generic.Emph */
pre.code  .gs { font-weight: bold } /* Generic.Strong */
pre.code  .kc { color: #66d9ef } /* Keyword.Constant */
pre.code  .kd { color: #66d9ef } /* Keyword.Declaration */
pre.code  .kn { color: #f92672 } /* Keyword.Namespace */
pre.code  .kp { color: #66d9ef } /* Keyword.Pseudo */
pre.code  .kr { color: #66d9ef } /* Keyword.Reserved */
pre.code  .kt { color: #66d9ef } /* Keyword.Type */
pre.code  .ld { color: #e6db74 } /* Literal.Date */
pre.code  .m { color: #ae81ff } /* Literal.Number */
pre.code  .s { color: #e6db74 } /* Literal.String */
pre.code  .na { color: #a6e22e } /* Name.Attribute */
pre.code  .nb { color: #f8f8f2 } /* Name.Builtin */
pre.code  .nc { color: #a6e22e } /* Name.Class */
pre.code  .no { color: #66d9ef } /* Name.Constant */
pre.code  .nd { color: #a6e22e } /* Name.Decorator */
pre.code  .ni { color: #f8f8f2 } /* Name.Entity */
pre.code  .ne { color: #a6e22e } /* Name.Exception */
pre.code  .nf { color: #a6e22e } /* Name.Function */
pre.code  .nl { color: #f8f8f2 } /* Name.Label */
pre.code  .nn { color: #f8f8f2 } /* Name.Namespace */
pre.code  .nx { color: #a6e22e } /* Name.Other */
pre.code  .py { color: #f8f8f2 } /* Name.Property */
pre.code  .nt { color: #f92672 } /* Name.Tag */
pre.code  .nv { color: #f8f8f2 } /* Name.Variable */
pre.code  .ow { color: #f92672 } /* Operator.Word */
pre.code  .w { color: #f8f8f2 } /* Text.Whitespace */
pre.code  .mf { color: #ae81ff } /* Literal.Number.Float */
pre.code  .mh { color: #ae81ff } /* Literal.Number.Hex */
pre.code  .mi { color: #ae81ff } /* Literal.Number.Integer */
pre.code  .mo { color: #ae81ff } /* Literal.Number.Oct */
pre.code  .sb { color: #e6db74 } /* Literal.String.Backtick */
pre.code  .sc { color: #e6db74 } /* Literal.String.Char */
pre.code  .sd { color: #e6db74 } /* Literal.String.Doc */
pre.code  .s2 { color: #e6db74 } /* Literal.String.Double */
pre.code  .se { color: #ae81ff } /* Literal.String.Escape */
pre.code  .sh { color: #e6db74 } /* Literal.String.Heredoc */
pre.code  .si { color: #e6db74 } /* Literal.String.Interpol */
pre.code  .sx { color: #e6db74 } /* Literal.String.Other */
pre.code  .sr { color: #e6db74 } /* Literal.String.Regex */
pre.code  .s1 { color: #e6db74 } /* Literal.String.Single */
pre.code  .ss { color: #e6db74 } /* Literal.String.Symbol */
pre.code  .bp { color: #f8f8f2 } /* Name.Builtin.Pseudo */
pre.code  .vc { color: #f8f8f2 } /* Name.Variable.Class */
pre.code  .vg { color: #f8f8f2 } /* Name.Variable.Global */
pre.code  .vi { color: #f8f8f2 } /* Name.Variable.Instance */
pre.code  .il { color: #ae81ff } /* Literal.Number.Integer.Long */


